@@ -1,7 +1,7 @@
 # -*- coding: UTF-8 -*-
 """
 Name: settings_ytdlp.py
-Porpose: YouTube Downloader setup dialog
+Porpose: Downloader setup dialog
 Compatibility: Python3, wxPython Phoenix
 Author: Gianluca Pernigotto <jeanlucperni@gmail.com>
 Copyleft - 2025 Gianluca Pernigotto <jeanlucperni@gmail.com>
@@ -34,7 +34,7 @@ from vidtuber.vt_sys.settings_manager import ConfigManager
 class YtdlpSettings(wx.Dialog):
     """
     Represents settings and configuration
-    storing of the YouTube Downloader.
+    storing of the Downloader.
     """
     # -----------------------------------------------------------------
 
